SelectOptionItem class

Implemented types

Constructors

SelectOptionItem(String value, String label)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

getID() → String
override
getLabel() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited