LiteDatabaseConfig class

Constructors

LiteDatabaseConfig({bool sqliteDisabled = false, bool inMemory = false, int version = 1, OnDatabaseCreateFn? onCreate, OnDatabaseVersionChangeFn? onUpgrade, OnDatabaseVersionChangeFn? onDowngrade, Duration lockDuration = const Duration(seconds: 5)})
const
LiteDatabaseConfig.disabled()
Returns a config with SQLite disabled — connection will be skipped.
factory
LiteDatabaseConfig.memory({OnDatabaseCreateFn? onCreate})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inMemory bool
final
lockDuration Duration
Duration in which the connection is considered "locked" after last usage.
final
onCreate → OnDatabaseCreateFn?
final
onDowngrade → OnDatabaseVersionChangeFn?
final
onUpgrade → OnDatabaseVersionChangeFn?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqliteDisabled bool
final
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited