SyncInfo class

Constructors

SyncInfo({required String tableName, required int syncAt, int? retentionDays, bool readOnly = false, bool writeOnly = false})
const
SyncInfo.fromMap(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
readOnly bool
final
retentionDays int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncAt int
final
tableName String
final
writeOnly bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited