SyncPayloadRequest class

Constructors

SyncPayloadRequest({required String tableName, required int syncAt, List<Map<String, Object?>> payload = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
payload List<Map<String, Object?>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncAt int
final
tableName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited