TableScript class

Constructors

TableScript({required String tableName, required String script, required int startSync, int? retentionDays, bool readOnly = false, bool writeOnly = false})
const
TableScript.fromMap(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
readOnly bool
final
retentionDays int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
script String
final
startSync int
final
tableName String
final
writeOnly bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited