close method
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
Implementation
@override
Future<void> close() async {
for (final timer in _timers.values) {
timer.cancel();
}
_timers.clear();
return super.close();
}