TableSyncGroup class

Constructors

TableSyncGroup({String? title, required List<String> tables, String? serviceID, Duration every = const Duration(minutes: 1), bool autoSync = true, bool syncOnStart = false})
const

Properties

autoSync bool
final
every Duration
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceID String?
final
syncOnStart bool
final
tables List<String>
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited