TableSyncGroupState class

Constructors

TableSyncGroupState({bool syncing = false, bool hasError = false, String errorMessage = '', DateTime? lastRun, bool autoSyncEnabled = true})
const

Properties

autoSyncEnabled bool
final
errorMessage String
final
hasError bool
final
hashCode int
The hash code for this object.
no setterinherited
lastRun DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncing bool
final

Methods

copyWith({bool? syncing, bool? hasError, String? errorMessage, DateTime? lastRun, bool? autoSyncEnabled}) TableSyncGroupState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited