TrackedBinaryState class

Constructors

TrackedBinaryState()
TrackedBinaryState.fromSyncedBase64(String? base64)
Creates an instance with synced base64 string (not modified).
factory
TrackedBinaryState.fromSyncedBytes(Uint8List? bytes)
Creates an instance with synced bytes (not modified).
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBase64() → String?
Returns base64 string of data.
getBase64IfModified() → String?
getBytes() → Uint8List?
Returns raw byte data.
getBytesIfModified() → Uint8List?
isEmpty() → bool
Returns true if there's no data.
isInitialized() → bool
Returns whether the asset has been initialized.
isModified() → bool
Returns whether the data has been modified.
isNotEmpty() → bool
markUnmodified() → void
Marks the asset as unmodified.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
syncFromBase64(String? base64) → void
Replaces data from base64 string without marking as modified.
syncFromBytes(Uint8List? bytes) → void
Replaces data from bytes without marking as modified.
syncFromFile(File file) → Future<void>
Replaces data from file without marking as modified.
toString() → String
A string representation of this object.
inherited
updateFromBase64(String base64) → void
Updates data from base64 and marks as modified.
updateFromBytes(Uint8List bytes) → void
Updates data from bytes and marks as modified.
updateFromFile(File file) → Future<void>
Updates data from file and marks as modified.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromSyncedFile(File file) → Future<TrackedBinaryState>
Creates an instance with synced file (not modified).