onInputSettled property
Called when the input reaches a stable state and can be safely reacted to.
Implementation
final FutureOr<void> Function(TextEditingCController txt)? onInputSettled;
Called when the input reaches a stable state and can be safely reacted to.
final FutureOr<void> Function(TextEditingCController txt)? onInputSettled;