TableSyncBloc class
Constructors
- TableSyncBloc(TableSyncConfig config)
Properties
- config → TableSyncConfig
-
final
-
groupIDs
→ List<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Whether the bloc is closed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → TableSyncState
-
The current state.
no setterinherited
-
stream
→ Stream<
TableSyncState> -
The current stream of states.
no setterinherited
-
visibleGroupIDs
→ List<
String> -
no setter
Methods
-
addError(
Object error, [StackTrace? stackTrace]) → void -
Reports an
errorwhich triggersonErrorwith an optional StackTrace.inherited -
close(
) → Future< void> - Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
-
disableGroup(
String groupID) → Future< void> -
emit(
TableSyncState state) → void -
Updates the
stateto the providedstate.emitdoes nothing if thestatebeing emitted is equal to the currentstate.inherited -
enableGroup(
String groupID, {bool start = true}) → Future< void> -
errorMessage(
String groupID) → String -
every(
String groupID) → Duration -
group(
String groupID) → TableSyncGroup -
hasError(
String groupID) → bool -
isAutoSyncEnabled(
String groupID) → bool -
isSyncing(
String groupID) → bool -
lastRun(
String groupID) → DateTime? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(
Change< TableSyncState> change) → void -
Called whenever a
changeoccurs with the givenchange. Achangeoccurs when a newstateis emitted.onChangeis called before thestateof thecubitis updated.onChangeis a great spot to add logging/analytics for a specificcubit.inherited -
onError(
Object error, StackTrace stackTrace) → void -
Called whenever an
erroroccurs and notifiesBlocObserver.onError.inherited -
startAll(
{bool syncOnStart = false}) → Future< void> -
startConfiguredGroups(
) → Future< void> -
startGroup(
String groupID, {bool syncOnStart = false}) → Future< void> -
stopAll(
) → Future< void> -
stopGroup(
String groupID) → Future< void> -
syncAll(
) → Future< void> -
syncGroup(
String groupID) → Future< void> -
syncStartupGroups(
) → Future< void> -
titleOf(
String groupID) → String -
toString(
) → String -
A string representation of this object.
inherited
-
updateGroupInterval(
String groupID, Duration duration) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited