TableSyncConfig class
Constructors
-
TableSyncConfig({String? defaultServiceID, required Map<
String, Object> groups}) -
TableSyncConfig.fromGroups({String? defaultServiceID, required Map<
String, TableSyncGroup> groups})
Properties
- defaultServiceID → String?
-
final
-
groups
→ Map<
String, TableSyncGroup> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited