TableSyncState class
Constructors
-
TableSyncState({Map<
String, TableSyncGroupState> groups = const {}, bool syncingAll = false}) -
const
Properties
-
groups
→ Map<
String, TableSyncGroupState> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syncingAll → bool
-
final
Methods
-
copyWith(
{Map< String, TableSyncGroupState> ? groups, bool? syncingAll}) → TableSyncState -
group(
String groupID) → TableSyncGroupState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateGroup(
String groupID, TableSyncGroupState update(TableSyncGroupState current)) → TableSyncState
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited