QueryController<T, Q> class
Constructors
-
QueryController({required FutureOr<T> fetchCallback(Q? query), Q? initialQuery, bool clearOnRefresh = false, T filterCallback(T data, String filter)?, bool onDataLoadDecision(T data)?, void onUpdate(T data)?})
-
Methods
-
addError(Object error, [StackTrace? stackTrace])
→ void
-
Reports an
error which triggers onError with an optional StackTrace.
inherited
-
applyFilter(String filter)
→ void
-
-
clearFilter()
→ void
-
-
close()
→ Future<void>
-
Closes the instance.
This method should be called when the instance is no longer needed.
Once
close is called, the instance can no longer be used.
inherited
-
emit(QueryState<T> state)
→ void
-
Updates the
state to the provided state.
emit does nothing if the state being emitted
is equal to the current state.
inherited
-
fetch({Q? query, bool silent = false})
→ Future<void>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(Change<QueryState<T>> change)
→ void
-
Called whenever a
change occurs with the given change.
A change occurs when a new state is emitted.
onChange is called before the state of the cubit is updated.
onChange is a great spot to add logging/analytics for a specific cubit.
inherited
-
onError(Object error, StackTrace stackTrace)
→ void
-
Called whenever an
error occurs and notifies BlocObserver.onError.
inherited
-
refetch()
→ Future<void>
-
-
refresh({bool silent = true})
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateQuery(Q query)
→ void
-